@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "yaml-imenu" "1.1.0"
+(define-package "yaml-imenu" "20250818.1432"
   "Enhancement of the imenu support in yaml-mode."
   '((emacs     "27.1")
     (yaml-mode "0"))
